@@ -30,6 +30,7 @@ from pathlib import Path
 from typing import TYPE_CHECKING, Any, Callable, Dict, Optional, Tuple, TypeVar
 
 import numpy as np
+from numba.extending import register_jitable
 from numpy.lib.recfunctions import structured_to_unstructured
 from scipy import integrate
 
@@ -166,10 +167,15 @@ class DropletBase:
             self.data = np.recarray(1, dtype=dtype)[0]
 
     def __init_subclass__(cls, **kwargs):  # @NoSelf
-        """register all subclassess to reconstruct them later"""
+        """modify subclasses of this base class"""
         super().__init_subclass__(**kwargs)
+
+        # register all subclassess to reconstruct them later
         cls._subclasses[cls.__name__] = cls
 
+        # create a staticmethod for merging droplet data
+        cls._merge_data = staticmethod(cls._make_merge_data())
+
     def __eq__(self, other):
         if not isinstance(other, self.__class__):
             return NotImplemented
@@ -208,6 +214,21 @@ class DropletBase:
         else:
             return self.from_data(self.data.copy())  # type: ignore
 
+    @classmethod
+    def _make_merge_data(cls) -> Callable[[np.ndarray, np.ndarray, np.ndarray], None]:
+        """factory for a function that merges the data of two droplets"""
+        raise NotImplementedError
+
+    def merge(self: TDroplet, other: TDroplet, *, inplace: bool = False) -> TDroplet:
+        """merge two droplets into one"""
+        if inplace:
+            self._merge_data(self.data, other.data, out=self.data)  # type: ignore
+            return self
+        else:
+            result = np.record(np.zeros_like(self.data))
+            self._merge_data(self.data, other.data, out=result)  # type: ignore
+            return self.__class__.from_data(result)  # type: ignore
+
     @property
     def data_bounds(self) -> Tuple[np.ndarray, np.ndarray]:
         """tuple: lower and upper bounds on the parameters"""
@@ -284,7 +305,7 @@ class SphericalDroplet(DropletBase):  # lgtm [py/missing-equals]
     @property
     def position(self) -> np.ndarray:
         """:class:`~numpy.ndarray`: the position of the droplet"""
-        return self.data["position"]  # type: ignore
+        return self.data["position"]
 
     @position.setter
     def position(self, value: np.ndarray):
@@ -325,7 +346,7 @@ class SphericalDroplet(DropletBase):  # lgtm [py/missing-equals]
             self.position - self.radius, self.position + self.radius
         )
 
-    def overlaps(self, other: "SphericalDroplet", grid: GridBase = None) -> bool:
+    def overlaps(self, other: SphericalDroplet, grid: GridBase = None) -> bool:
         """determine whether another droplet overlaps with this one
 
         Note that this function so far only compares the distances of the
@@ -349,6 +370,27 @@ class SphericalDroplet(DropletBase):  # lgtm [py/missing-equals]
             distance = grid.distance_real(self.position, other.position)
         return distance < self.radius + other.radius
 
+    @classmethod
+    def _make_merge_data(cls) -> Callable[[np.ndarray, np.ndarray, np.ndarray], None]:
+        """factory for a function that merges the data of two droplets"""
+        radius_from_volume = spherical.make_radius_from_volume_nd_compiled()
+        volume_from_radius = spherical.make_volume_from_radius_nd_compiled()
+
+        @register_jitable
+        def merge_data(drop1: np.ndarray, drop2: np.ndarray, out: np.ndarray) -> None:
+            """merge the data of two droplets"""
+            dim = len(drop1.position)  # type: ignore
+
+            V1 = volume_from_radius(drop1.radius, dim)  # type: ignore
+            V2 = volume_from_radius(drop2.radius, dim)  # type: ignore
+            volume = V1 + V2
+            out.radius = radius_from_volume(volume, dim)  # type: ignore
+
+            # adjust droplet position
+            out.position[...] = (V1 * drop1.position + V2 * drop2.position) / volume  # type: ignore
+
+        return merge_data  # type: ignore
+
     @preserve_scalars
     def interface_position(self, *args) -> np.ndarray:
         r"""calculates the position of the interface of the droplet
@@ -577,6 +619,19 @@ class DiffuseDroplet(SphericalDroplet):
         dtype = super().get_dtype(**kwargs)
         return dtype + [("interface_width", float)]
 
+    @classmethod
+    def _make_merge_data(cls) -> Callable[[np.ndarray, np.ndarray, np.ndarray], None]:
+        """factory for a function that merges the data of two droplets"""
+        parent_merge = super()._make_merge_data()
+
+        @register_jitable
+        def merge_data(drop1: np.ndarray, drop2: np.ndarray, out: np.ndarray) -> None:
+            """merge the data of two droplets"""
+            parent_merge(drop1, drop2, out)
+            out.interface_width = (drop1.interface_width + drop2.interface_width) / 2  # type: ignore
+
+        return merge_data  # type: ignore
+
     @property
     def interface_width(self) -> Optional[float]:
         """float: the width of the interface of this droplet"""
@@ -931,7 +986,7 @@ class PerturbedDroplet2D(PerturbedDropletBase):
         length: float = 4
         for n, (a, b) in enumerate(iterate_in_pairs(self.amplitudes), 1):  # no 0th mode
             length += n**2 * (a**2 + b**2)
-        return np.pi * self.radius * length / 2  # type: ignore
+        return np.pi * self.radius * length / 2
 
     def _get_mpl_patch(self, dim=2, **kwargs):
         """return the patch representing the droplet for plotting
